@@ -1,4 +1,4 @@
-/*  $Id: french-conjugator.cpp,v 1.12 2006/08/29 01:13:25 sarrazip Exp $
+/*  $Id: french-conjugator.cpp,v 1.14 2008/01/24 03:28:21 sarrazip Exp $
     french-conjugator.cpp - Conjugation of French verbs
 
     verbiste - French conjugation system
@@ -35,6 +35,7 @@
 
 #include <iostream>
 #include <vector>
+#include <string.h>
 
 using namespace std;
 using namespace verbiste;
@@ -52,6 +53,7 @@ static struct option knownOptions[] =
     { "tense",          required_argument,      NULL, 't' },
     { "template",       required_argument,      NULL, 'l' },
     { "pronouns",       no_argument,            NULL, 'p' },
+    { "utf8",           no_argument,            NULL, 'u' },
 
     { NULL, 0, NULL, 0 }  // marks the end
 };
@@ -240,6 +242,7 @@ displayHelp()
 "--tense=T          Only display tense T (present, past, etc)\n"
 "--template=T       Use template T to conjugate the verbs\n"
 "--pronouns         Include pronouns in the displayed conjugation\n"
+"--utf8             Assume that the terminal uses UTF-8 instead of Latin-1\n"
 "\n"
 "See the " << commandName << "(1) manual page for details.\n"
 "\n"
@@ -310,6 +313,10 @@ main(int argc, char *argv[])
 		displayHelp();
 		return EXIT_SUCCESS;
 
+	    case 'u':
+	    	utf8Mode = true;
+		break;
+
 	    default:
 		displayHelp();
 		return EXIT_FAILURE;
