@@ -1,4 +1,4 @@
-/*  $Id: french-deconjugator.cpp,v 1.10 2006/07/08 19:20:05 sarrazip Exp $
+/*  $Id: french-deconjugator.cpp,v 1.12 2008/01/24 03:28:21 sarrazip Exp $
     french-deconjugator.cpp - Analyzer of conjugated French verbs
 
     verbiste - French conjugation system
@@ -35,6 +35,7 @@
 
 #include <iostream>
 #include <vector>
+#include <string.h>
 
 using namespace std;
 using namespace verbiste;
@@ -48,6 +49,7 @@ static struct option knownOptions[] =
 {
     { "help",          no_argument,       NULL, 'h' },
     { "version",       no_argument,       NULL, 'v' },
+    { "utf8",          no_argument,       NULL, 'u' },
 
     { NULL, 0, NULL, 0 }  // marks the end
 };
@@ -144,6 +146,7 @@ displayHelp()
 "Known options:\n"
 "--help             Display this help page and exit\n"
 "--version          Display this program's version number and exit\n"
+"--utf8             Assume that the terminal uses UTF-8 instead of Latin-1\n"
 "\n"
 "See the " << commandName << "(1) manual page for details.\n"
 "\n"
@@ -179,6 +182,10 @@ main(int argc, char *argv[])
 		displayHelp();
 		return EXIT_SUCCESS;
 
+	    case 'u':
+	    	utf8Mode = true;
+		break;
+
 	    default:
 		displayHelp();
 		return EXIT_FAILURE;
