@@ -1,4 +1,4 @@
-/*  $Id: panel-applet.cpp,v 1.12 2006/08/28 19:05:25 sarrazip Exp $
+/*  $Id: panel-applet.cpp,v 1.13 2008/02/03 07:10:58 sarrazip Exp $
     panel-applet.cpp - GNOME Panel applet main functions
 
     verbiste - French conjugation system
@@ -81,6 +81,21 @@ onKeyPressInEntry(GtkWidget *entry, GdkEventKey *event, gpointer)
 }
 
 
+static
+gboolean
+entry_button_press_event(GtkWidget *widget,
+			GdkEventButton *event,
+			gpointer *applet)
+{
+    panel_applet_request_focus((PanelApplet *) applet, event->time);
+  
+    /* We just wanted to insert the above function call before the
+     * default action...
+    */
+    return FALSE;
+}
+
+
 static const BonoboUIVerb applet_menu_verbs[] =
 {
     BONOBO_UI_VERB("VerbisteAbout", onAbout),
@@ -106,6 +121,9 @@ appletFill(PanelApplet *applet, const gchar *iid, gpointer)
 
     g_signal_connect(G_OBJECT(appletEntry), "key-press-event",
 			G_CALLBACK(onKeyPressInEntry), NULL);
+    
+    g_signal_connect(G_OBJECT (appletEntry), "button_press_event",
+			G_CALLBACK(entry_button_press_event), applet);
 
     GtkWidget *hbox = gtk_hbox_new(FALSE, 2);
     gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
