@@ -1,4 +1,4 @@
-/*  $Id: main-window.cpp,v 1.3 2007/01/04 03:30:14 sarrazip Exp $
+/*  $Id: main-window.cpp,v 1.7 2007/02/18 03:48:09 sarrazip Exp $
     main-window.cpp - Input and conjugation window
 
     verbiste - French conjugation system
@@ -100,6 +100,17 @@ ResultPage::ResultPage()
 /*****************************************************************************/
 
 
+static
+void
+hideOrQuit(GtkWidget *, gpointer)
+{
+    if (hideOnDelete)
+	gtk_widget_hide(resultWin);
+    else
+	gtk_main_quit();
+}
+
+
 static
 gboolean
 onKeyPressInResultWin(GtkWidget *, GdkEventKey *event, gpointer)
@@ -108,10 +119,7 @@ onKeyPressInResultWin(GtkWidget *, GdkEventKey *event, gpointer)
 
     if (event->keyval == GDK_w && (event->state & GDK_CONTROL_MASK) != 0)
     {
-	if (hideOnDelete)
-	    gtk_widget_hide(resultWin);
-	else
-	    gtk_main_quit();
+	hideOrQuit(NULL, NULL);
 	return TRUE;
     }
 
@@ -454,6 +462,14 @@ onAboutButton(GtkWidget *, gpointer)
 }
 
 
+static
+void
+onShowPronounsToggled(GtkToggleButton *, gpointer)
+{
+    onConjugateButton(NULL, NULL);
+}
+
+
 static
 void
 showResultWin()
@@ -462,7 +478,7 @@ showResultWin()
     {
 	resultWin = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(resultWin), PACKAGE_FULL_NAME);
-	gtk_window_set_default_size(GTK_WINDOW(resultWin), 380, 525);
+	gtk_window_set_default_size(GTK_WINDOW(resultWin), 380, 570);
 	gtk_container_set_border_width(GTK_CONTAINER(resultWin), 4);
 
 	if (hideOnDelete)
@@ -507,17 +523,12 @@ showResultWin()
 	g_signal_connect(G_OBJECT(conjButton), "clicked",
 				    G_CALLBACK(onConjugateButton), NULL);
 
-	saveButton = gtk_button_new_with_mnemonic(_("_Save..."));
+	saveButton = gtk_button_new_from_stock(GTK_STOCK_SAVE_AS);
 	gtk_widget_set_sensitive(GTK_WIDGET(saveButton), false);
 	gtk_box_pack_start(GTK_BOX(promptBox), saveButton, FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT(saveButton), "clicked",
 				    G_CALLBACK(onSaveButton), NULL);
 
-	GtkWidget *aboutButton = gtk_button_new_with_mnemonic(_("_About..."));
-	gtk_box_pack_end(GTK_BOX(promptBox), aboutButton, FALSE, FALSE, 0);
-	g_signal_connect(G_OBJECT(aboutButton), "clicked",
-				    G_CALLBACK(onAboutButton), NULL);
-
 
 	/*
 	    Create an options box.
@@ -527,6 +538,8 @@ showResultWin()
 							_("Show _Pronouns"));
 	gtk_box_pack_start(GTK_BOX(optionsBox), showPronounsCB,
 							FALSE, FALSE, 0);
+	g_signal_connect(G_OBJECT(showPronounsCB), "toggled",
+				    G_CALLBACK(onShowPronounsToggled), NULL);
 
 
 	/*
@@ -536,6 +549,24 @@ showResultWin()
 	gtk_notebook_set_scrollable(GTK_NOTEBOOK(resultNotebook), TRUE);
 
 
+
+	/*
+	    Create a button box at the bottom.
+	*/
+	GtkWidget *bottomBox = gtk_hbox_new(FALSE, SP);
+
+	GtkWidget *closeButton = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
+	gtk_box_pack_end(GTK_BOX(bottomBox), closeButton, FALSE, FALSE, 0);
+	g_signal_connect(G_OBJECT(closeButton), "clicked",
+				    G_CALLBACK(hideOrQuit), NULL);
+
+	GtkWidget *aboutButton = gtk_button_new_from_stock(GTK_STOCK_ABOUT);
+	g_signal_connect(G_OBJECT(aboutButton), "clicked",
+				    G_CALLBACK(onAboutButton), NULL);
+	gtk_box_pack_end(GTK_BOX(bottomBox), aboutButton, FALSE, FALSE, 0);
+
+
+
 	/*
 	    Finish the window setup:
 	*/
@@ -543,6 +574,7 @@ showResultWin()
 	gtk_box_pack_start(GTK_BOX(vbox), promptBox, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), optionsBox, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), resultNotebook, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), bottomBox, FALSE, FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(resultWin), vbox);
 	set_window_icon_to_default(resultWin);
 	gtk_widget_show_all(GTK_WIDGET(resultWin));
