@@ -1,8 +1,8 @@
-/*  $Id: FrenchVerbDictionary.h,v 1.20 2004/03/23 22:35:56 sarrazip Exp $
+/*  $Id: FrenchVerbDictionary.h,v 1.22 2005/03/13 04:03:26 sarrazip Exp $
     FrenchVerbDictionary.h - Dictionary of verbs and conjugation templates
 
     verbiste - French conjugation system
-    Copyright (C) 2003 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2003-2005 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -33,6 +33,7 @@
 #include <assert.h>
 #include <stdexcept>
 #include <vector>
+#include <set>
 #include <string>
 
 
@@ -254,12 +255,30 @@ public:
 				store the results; the result is a list of
 				"persons", and a person is a list of
 				"inflections"
+	@param	includePronouns	put pronouns before conjugated verbs in the
+				modes where pronouns are used
+	@param	aspirateH	notifies this function that the verb starts
+				with an aspirate h (e.g., "hacher", which
+				gives "je hache") instead of a silent h
+				(e.g., "habiter", which gives "j'habite")
     */
     static void generateTense(const std::string &radical,
 			const TemplateSpec &templ,
 			Mode mode,
 			Tense tense,
-			std::vector< std::vector<std::string> > &dest) throw();
+			std::vector< std::vector<std::string> > &dest,
+			bool includePronouns = false,
+			bool aspirateH = false) throw();
+
+    /** Indicates if the given verb starts with an aspirate h.
+	An aspirate h means that one cannot make a contraction or liaison
+	in front of the word.  For example, "hacher" has an aspirate h
+	and this means that one says "je hache" and not "j'hache".
+	The verb "habiter" however does not have an aspirate h, so one
+	says "j'habite" and not "je habite".
+    */
+    bool isVerbStartingWithAspirateH(
+				const std::string &infinitive) const throw();
 
 private:
 
@@ -320,6 +339,7 @@ private:
 
     ConjugationSystem conjugSys;
     VerbTable knownVerbs;
+    std::set<std::string> aspirateHVerbs;
     InflectionTable inflectionTable;
     iconv_t toUTF8;
     iconv_t toLatin1;
